<?php

/**
 * Enqueue the parent theme stylesheet.
 */

function vantage_child_enqueue_parent_style() {
    wp_enqueue_style( 'vantage-parent-style', get_template_directory_uri() . '/style.css' );
}
add_action( 'wp_enqueue_scripts', 'vantage_child_enqueue_parent_style', 8 );

if ( ! function_exists( 'vantage_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since vantage 1.0
 */
function vantage_posted_on() {
	$posted_on_parts = array(
		'on' => __( 'Posted on <a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a><time class="updated" datetime="%5$s">%6$s</time>', 'vantage'),
		'by' => __( '<span class="byline"> by <span class="author vcard"><a class="url fn n" href="%7$s" title="%8$s" rel="author">%9$s</a></span></span>', 'vantage' ),
	);
	$posted_on_parts = apply_filters('vantage_post_on_parts', $posted_on_parts);


	$posted_on = sprintf( implode(' ', $posted_on_parts),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		apply_filters('vantage_post_on_date', esc_html( get_the_date() )),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'vantage' ), get_the_author() ) ),
		get_the_author()
	);
	echo apply_filters('vantage_posted_on', $posted_on);
}
endif;

if( !function_exists( 'vantage_get_archive_title' ) ) :
/**
 * Return the archive title depending on which page is being displayed.
 * 
 * @since vantage 1.0
 */
function vantage_get_archive_title(){
	$title = '';
	global $wp_query;
	if ( is_category() ) {
		$title = sprintf( __( '%s', 'vantage' ), '<span>' . single_cat_title( '', false ) . '</span>' );

	}
	elseif ( is_tag() ) {
		$title = sprintf( __( '%s', 'vantage' ), '<span>' . single_tag_title( '', false ) . '</span>' );

	}
	elseif ( is_author() ) {
		the_post();
		$title = sprintf( __( '%s', 'vantage' ), '<span class="vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>' );
		rewind_posts();

	}
	elseif ( is_day() ) {
		$title = sprintf( __( '%s', 'vantage' ), '<span>' . get_the_date() . '</span>' );

	}
	elseif ( is_month() ) {
		$title = sprintf( __( '%s', 'vantage' ), '<span>' . get_the_date( 'F Y' ) . '</span>' );

	}
	elseif ( is_year() ) {
		$title = sprintf( __( '%s', 'vantage' ), '<span>' . get_the_date( 'Y' ) . '</span>' );

	}
	elseif ( !empty($wp_query->query_vars['taxonomy']) ) {
		$value = get_query_var($wp_query->query_vars['taxonomy']);
		$term = get_term_by('slug',$value,$wp_query->query_vars['taxonomy']);
		$tax = get_taxonomy( $wp_query->query_vars['taxonomy'] );
		$title = sprintf( __( '%s: %s', 'vantage' ), $tax->label, $term->name );
	}
	else {
		$title = __( 'Archives', 'vantage' );
	}
	
	return apply_filters('vantage_archive_title', $title);
}
endif;